@@ -6,6 +6,13 @@ cli.add_option('-q', '--quiet', help='Do not output any message')
 cli.add_option('--verbose', help='Increase verbosity')
 
 
+def processor(quiet: bool, verbose: bool):
+    print(f'Processing {quiet=} and {verbose=}')
+
+
+cli.set_options_processor(processor)
+
+
 @cli.command(cmd='foo',
              help='Run foo command')
 def foo_main(
@@ -15,7 +22,12 @@ def foo_main(
         foo2: str = Option(..., '-f', '--foo2', help='Foo2 arguments'),
         foo3: str = Option(None, '-g', '--foo3', help='Foo3 arguments'),
 ):
-    pass
+    for name, value in [('quiet', quiet),
+                        ('verbose', verbose),
+                        ('foo1', foo1),
+                        ('foo2', foo2),
+                        ('foo3', foo3)]:
+        print(f'{name} = {value} ({type(value)})')
 
 
 @cli.command(cmd='bar', help='Run bar command')
@@ -42,7 +54,12 @@ def toto_main(
         foo1: int = Option(..., help='Foo arguments'),
         foo2: str = Option(..., '-f', '--foo2', help='Foo2 arguments'),
 ):
-    pass
+    for name, value in [('test', test),
+                        ('quiet', quiet),
+                        ('verbose', verbose),
+                        ('foo1', foo1),
+                        ('foo2', foo2)]:
+        print(f'{name} = {value} ({type(value)})')
 
 
 if __name__ == '__main__':
